@@ -33,19 +33,19 @@ if you want to run it as a service user simplevisor-control as init script.
 
 Author: Massimo.Paladin@gmail.com
 
-Copyright (C) CERN 2013-2014
+Copyright (C) CERN 2013-2021
 """
 
-AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
-COPYRIGHT = "Copyright (C) CERN 2013-2014"
-VERSION = "1.1"
-DATE = "1 Oct 2014"
-__author__ = AUTHOR
-__version__ = VERSION
-__date__ = DATE
-
 import sys
 import simplevisor.mtb as mtb
 
+AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
+COPYRIGHT = "Copyright (C) CERN 2013-2021"
+VERSION = "1.3"
+DATE = "3 Nov 2021"
+__author__ = AUTHOR
+__version__ = VERSION
+__date__ = DATE
+
 if "mtb" not in sys.modules:
     sys.modules["mtb"] = mtb
