@@ -12,7 +12,7 @@ either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 
-Copyright (C) 2013-2014 CERN
+Copyright (C) CERN 2013-2021
 """
 from simplevisor.errors import ServiceError
 from simplevisor.service import Service
@@ -113,14 +113,14 @@ class ServiceTest(unittest.TestCase):
             opts['logname'] = TEST_LOGNAME
             svc = Service(**opts)
             svc.cond_start(careful=True)
-            self.assertEquals(
+            self.assertEqual(
                 0, svc.status()[0],
                 "%s should be started" % (svc.name,))
             self.assertTrue(
                 svc.check()[0],
                 "check should have returned true for %s" % (svc.name, ))
             svc.cond_stop(careful=True)
-            self.assertEquals(
+            self.assertEqual(
                 3, svc.status()[0],
                 "%s should be stopped" % (svc.name,))
             self.assertFalse(
@@ -151,5 +151,6 @@ class ServiceTest(unittest.TestCase):
             service._opts["status"])
         print("...service daemon option ok")
 
+
 if __name__ == "__main__":
     unittest.main()
